#
# spec file for package python-persistent
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2013 LISA GmbH, Bingen, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-persistent
Version:        4.0.9
Release:        5.2
Url:            https://github.com/zopefoundation/persistent
Summary:        Translucent persistent objects
License:        ZPL-2.1
Group:          Development/Languages/Python
Source:         https://pypi.python.org/packages/source/p/persistent/persistent-%{version}.tar.gz
# PATCH-FIX-UPSTREAM fix_32-bit_timestamp_hashcode.patch -- fix timestamp hash computation on 32-bit platform
Patch:          fix_32-bit_timestamp_hashcode.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python-devel
BuildRequires:  python-setuptools
BuildRequires:  python-zope.interface
Requires:       python-zope.interface
# Documentation requirements:
BuildRequires:  python-Sphinx
BuildRequires:  python-repoze.sphinx.autointerface

%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitearch: %global python_sitearch %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib(1)")}
%endif

%description
This package contains a generic persistence implementation for Python. It forms
the core protocol for making objects interact "transparently" with a database
such as the ZODB.

%package devel
Summary:        Translucent persistent objects
Group:          Development/Languages/Python
Requires:       %{name} = %{version}

%description devel
This package contains the files needed for binding the %{name} C module.

%package doc
Summary:        Translucent persistent objects
Group:          Development/Languages/Python
Requires:       %{name} = %{version}

%description doc
This package contains documentation files for %{name}.

%prep
%setup -q -n persistent-%{version}
%patch -p1

%build
python setup.py build
python setup.py build_sphinx && rm build/sphinx/html/.buildinfo

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
# don't bother with development files
rm %{buildroot}%python_sitearch/persistent/*.c

%check
python setup.py -q test

%files
%defattr(-,root,root,-)
%doc CHANGES.rst COPYRIGHT.txt LICENSE.txt README.rst
%exclude %python_sitearch/persistent/*.h
%python_sitearch/*

%files devel
%defattr(-,root,root,-)
%dir %py_incdir/persistent
%py_incdir/persistent/*.h
%python_sitearch/persistent/*.h

%files doc
%defattr(-,root,root,-)
%doc build/sphinx/html/

%changelog
* Sun May 10 2015 benoit.monin@gmx.fr
- update to version 4.0.9:
  * Make the C and Python TimeStamp objects behave more alike
  * Intern keys of object state in __setstate__ to reduce memory
    usage when unpickling multiple objects with the same attributes
  * Add support for PyPy3
  * 100%% branch coverage
- additional changes from version 4.0.8:
  * Add support for Python 3.4
  * In pure-Python Persistent, avoid loading state in _p_activate
    for non-ghost objects (which could corrupt their state). (PR #9)
  * In pure-Python, and don’t throw POSKeyError if _p_activate is
    called on an object that has never been committed. (PR #9)
  * In pure-Python Persistent, avoid calling a subclass’s
    __setattr__ at instance creation time. (PR #8)
  * Make it possible to delete _p_jar / _p_oid of a pure-Python
    Persistent object which has been removed from the jar’s cache
    (fixes aborting a ZODB Connection that has added objects).
    (PR #7)
- additional changes from version 4.0.7:
  * Avoid a KeyError from _p_accessed() on newly-created objects
    under pure-Python: these objects may be assigned to a jar, but
    not yet added to its cache. (PR #6)
  * Avoid a failure in Persistent.__setstate__ when the state dict
    contains exactly two keys. (PR #5)
  * Fix a hang in picklecache invalidation if OIDs are manually
    passed out-of-order. (PR #4)
  * Add PURE_PYTHON environment variable support: if set, the C
    extensions will not be built, imported, or tested
- update project URL
- point the source URL to pypi
- drop type-mismatch.patch: fixed upstream
- add fix_32-bit_timestamp_hashcode.patch: fix timestamp hash
  computation on 32 bit platform
- pass -q to test to avoid spamming the build log
- rename CHANGES.txt and README.txt to CHANGES.rst and README.rst:
  changed upstream
* Fri Mar 21 2014 schwab@linux-m68k.org
- type-mismatch.patch: Use Py_ssize_t rather than PY_LONG_LONG for sizes
* Mon Jul 29 2013 hpj@urpla.net
- version 4.0.6: initial build
